/*
  a basic player
  Copyright (C) 1998  Martin Vogt

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation.

  For more information look at the file COPYRIGHT in this package

 */


#include "kmpgPlayer.h"



KmpgPlayer::KmpgPlayer(QWidget *parent, const char *name) :
  QWidget(parent,name) { 

  dropZone = new KDNDDropZone( this, DndURL );
  connect( dropZone, SIGNAL( dropAction( KDNDDropZone* )), SLOT( onDrop( KDNDDropZone*)));
  setBackgroundColor (QColor(0,0,0));
  buildGUI();
}


KmpgPlayer::~KmpgPlayer() {
  // Every device in the tree must be deleted seperatley:
  delete multicastDevice;
  delete dropZone;
  
} 


/*
  The yafDecoder cannot be handled like an ordinary
  device (on this level).
*/
void KmpgPlayer::setGenericStreamProducer(GenericStreamProducer* aDecoder) {
  MetaPlayer::setGenericStreamProducer(aDecoder);
  decoderWidget->setDevice(aDecoder);
}



OutputDevice* KmpgPlayer::getInternalDeviceTree() {
  // this method is used by the metaPlayer. It return
  // the root node of the devicetree.
  return multicastDevice;
}


void KmpgPlayer::addListener(NodeDevice* listener) {
  multicastDevice->addListener(listener);
}


int KmpgPlayer::open(KURL* url) {
  cout << "open:"<<url->path()<<endl;
  return MetaPlayer::open((char*)url->path());
}


void KmpgPlayer::volumeFilterActive(int active) {
  volumeWidget->setFilter(active);
}


void KmpgPlayer::buildGUI() {
  OutputDevice* outputDevice;
  QBoxLayout* topLayout = new QVBoxLayout( this, 1 );

  QBoxLayout* b = new QHBoxLayout();

  topLayout->addLayout(b);


  multicastDevice = new MulticastDevice();

  guiSpectrumAnalyser = new GuiSpectrumAnalyser(this);
  outputDevice=guiSpectrumAnalyser->getDevice();
  b->addWidget(guiSpectrumAnalyser);
  multicastDevice->addListener(outputDevice);

  statusWidget = new StatusWidget(this);
  outputDevice=statusWidget->getDevice();
  b->addWidget(statusWidget);
  multicastDevice->addListener(outputDevice);

  timerWidget = new TimerWidget(this);
  outputDevice=timerWidget->getDevice();
  b->addWidget(timerWidget);
  multicastDevice->addListener(outputDevice);


  volumeWidget = new VolumeWidget(this);
  volumeWidget->buildGui();
  outputDevice=volumeWidget->getDevice();
  b->addWidget(volumeWidget);
  multicastDevice->addListener(outputDevice);


  
  infoWidget = new InfoWidget(this);
  outputDevice=infoWidget->getDevice();
  topLayout->addWidget(infoWidget);
  multicastDevice->addListener(outputDevice);

  decoderWidget = new DecoderWidget(this); 
  decoderWidget->buildGui();
  topLayout->addWidget( decoderWidget );

}


void KmpgPlayer::onDrop( KDNDDropZone* zone) {
  QStrList strlist;
  char *str;
  
  strlist = zone->getURLList();
  str=strlist.first(); 
  if (str != NULL) {
    KURL url( str );
    char *path = url.path();
    open(&url);
    cout << "dropped:"<<path<<endl;
  }
}


