/*
  a basic player
  Copyright (C) 1998  Martin Vogt

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation.

  For more information look at the file COPYRIGHT in this package

 */


#include "guiPlayer6.h"



GuiPlayer::GuiPlayer() { 
  resize(200,120);
  buildGUI();
}


GuiPlayer::~GuiPlayer() {
  // Every device in the tree must be deleted seperatley:
  delete multicastDevice;
}

/*
  The yafDecoder cannot be handled like an ordinary
  device (on this level).
*/
void GuiPlayer::setGenericStreamProducer(GenericStreamProducer* aDecoder) {
  MetaPlayer::setGenericStreamProducer(aDecoder);
  guiDecoder->setDevice(aDecoder);
}



OutputDevice* GuiPlayer::getInternalDeviceTree() {
  // this method is used by the metaPlayer. It return
  // the root node of the devicetree.
  return multicastDevice;
}


void GuiPlayer::addListener(NodeDevice* listener) {
  multicastDevice->addListener(listener);
}


void GuiPlayer::buildGUI() {
  OutputDevice* outputDevice;
  QBoxLayout* topLayout = new QVBoxLayout( this, 5 );

  QBoxLayout* b = new QHBoxLayout();

  topLayout->addLayout(b);


  multicastDevice = new MulticastDevice();

  guiVolumeDevice = new GuiVolumeDevice(this);
  guiVolumeDevice->buildGui();
  guiVolumeDevice->setFilter(true);
  guiVolumeDevice->setGeometry( 10, 10, 80, 80 );
  guiVolumeDevice->show();
  outputDevice=guiVolumeDevice->getDevice();
  b->addWidget(guiVolumeDevice , AlignLeft|AlignTop|AlignBottom );
  multicastDevice->addListener(outputDevice);


  
  guiInfoDevice = new GuiInfoDevice(this);
  guiInfoDevice->setGeometry( 10, 10, 80, 200 );
  guiInfoDevice->show();
  outputDevice=guiInfoDevice->getDevice();
  b->addWidget(guiInfoDevice , AlignLeft|AlignTop|AlignBottom );
  multicastDevice->addListener(outputDevice);

  
  guiTimerDevice = new GuiTimerDevice(this);
  guiTimerDevice->setGeometry( 10, 10, 80, 80 );
  guiTimerDevice->show();
  outputDevice=guiTimerDevice->getDevice();
  b->addWidget(guiTimerDevice , AlignLeft|AlignTop|AlignBottom );
  multicastDevice->addListener(outputDevice);

  guiStatusDevice = new GuiStatusDevice(this);
  guiStatusDevice->setGeometry( 10, 10, 80, 80 );
  guiStatusDevice->show();
  outputDevice=guiStatusDevice->getDevice();
  b->addWidget(guiStatusDevice , AlignLeft|AlignTop|AlignBottom );
  multicastDevice->addListener(outputDevice);

  guiDecoder = new GuiDecoder(this);
  guiDecoder->setGeometry( 10, 10, 100, 100 );
  guiDecoder->show();
  b->addWidget(guiDecoder , AlignLeft|AlignTop|AlignBottom );
  

  topLayout->addWidget( guiDecoder );
  topLayout->activate();
}
