/*
  In a client we store the state of the thread
  Copyright (C) 1998  Martin Vogt

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation.

  For more information look at the file COPYRIGHT in this package

 */





#ifndef __THREAD_STATE_H
#define __THREAD_STATE_H


#include <iostream.h>
#include <pthread.h>


/**
  The ThreadState class stores information if the thread
  is Playing,stopped, paused.
  <p>
  This library has a concept of "producers" and "devices"
  Producers are implemented as a thread. Sometimes
  The user want to stop the thread or pause it.
  This must be stored somewhere. And what counts more
  that this state must be send to all connected
  device.
  Eg. A fileDevice (which writes a stream to disk) must
  know when the stream reaches "eof".
  This means that the thread stops. Thus the thread must
  deliver a "stop" message to the connected listeners (devices)
  <p>
  A streamProducer derives from this class. A streamProducer
  works very closley together with a "producer".
  (stupid name confusion : 
    
     streamProducer - a device which creates a thread and _delivers_ data
     "producer"     - a interface class which _create_ data
  )
  <p>
  The streamproducer enters the producer gets the data and then delivers
  the data.

*/

#define _MAX_THREAD_ENTRIES      10


typedef struct {
  int valid;
  int state;
} ThreadEntry;


class ThreadState {

  ThreadEntry* threadEntryArray[_MAX_THREAD_ENTRIES];
  int freePos;
  int readPos;
  int fillgrade;
  pthread_mutex_t stateMut;


 public:
  ThreadState();
  virtual ~ThreadState();

  virtual void setProducerEnter(int allow);
  virtual void enqueueThreadState(int state);

  virtual int hasState();
  virtual int dequeueThreadState();

};

#endif


